{ config, lib, pkgs, ... }: {
  imports = [ ./hardware-configuration.nix ];

  boot = {
    loader.systemd-boot.enable = true;
    loader.efi.canTouchEfiVariables = true;
  };

  nix = {
    buildMachines = [ ];
    distributedBuilds = false;
    settings.experimental-features = [ "nix-command" "flakes" ];
  };

  networking = {
    hostName = "eve-psr-nix0";
    firewall = {
      allowedTCPPorts = [ 22 80 443 ];
      allowedUDPPorts = [ 22 80 443 ];
    };
  };

  time.timeZone = "America/Chicago";

  services.openssh.enable = true;
  virtualisation.docker = {
    enable = true;
    liveRestore = false;
  };

  environment.systemPackages = with pkgs; [ git pciutils vim wget ];

  programs.zsh.enable = true;
  users = {
    defaultUserShell = pkgs.zsh;
    users = {
      sezycei = {
        isNormalUser = true;
        initialPassword = "bootMaster";
        extraGroups = [ "wheel" "docker" ];
        packages = with pkgs; [ byobu tmux stack ];
      };
      torrent = {
        isNormalUser = true;
        initialPassword = "torrentUserTemp";
      };
    };

  };

  system.stateVersion = "22.11";
}
